@@ -14,20 +14,30 @@ from .util import (
 )
 
 
-def _compress_image(args):
-    cmd = [
-        "convert",
-        "-quality",
-        str(args["quality"]),
-        "-background",
-        "white",
-        "-alpha",
-        "remove",
-        "-alpha",
-        "off",
-        args["input"] + "[0]",  # add [0] to use only the first page of TIFFs
-        args["output"],
-    ]
+def _compress_file(args):
+    if (args["is_image"]):
+        # image, use convert (imagemagick)
+        cmd = [
+            "convert",
+            "-quality",
+            str(args["quality"]),
+            "-background",
+            "white",
+            "-alpha",
+            "remove",
+            "-alpha",
+            "off",
+            args["input"] + "[0]",  # add [0] to use only the first page of TIFFs
+            args["output"],
+        ]
+    else:
+        # video, use ffmpeg
+        cmd = [
+            "ffmpeg",
+            "-i",
+            args["input"],
+            args["output"]
+        ]
     run_command(cmd, verbose=args["verbose"])
 
 
@@ -57,6 +67,9 @@ class CompressPptx:
         skip_transparent_images=False,
         verbose=False,
         force=False,
+        compress_media=False,
+        recompress_jpeg=False,
+        use_libreoffice=False
     ) -> None:
         self.input_file = input_file
         self.output_file = output_file
@@ -66,10 +79,28 @@ class CompressPptx:
         self.skip_transparent_images = bool(skip_transparent_images)
         self.verbose = bool(verbose)
         self.force = bool(force)
+        self.compress_media=compress_media
+        self.use_libreoffice = use_libreoffice
+        ## file extensions and conversions
+        self.image_extensions = ['.png', '.emf', '.tiff']
+        if recompress_jpeg: self.image_extensions.extend(['.jpg', '.jpeg'])
+        self.converted_image_extension = ".jpg"
 
-        self.image_list = []
+        self.video_extensions = ['.mov', '.avi', '.mp4']
+        self.converted_video_extensions = ".mp4"
+        self.audio_extensions = ['.mp3', '.wav']
+        self.converted_audio_extensions = ".mp3"
 
-        for expected_cmd in ["convert", "identify"]:
+
+        self.file_list = []
+
+        required_executables = ["convert", "identify"]
+        ## add ffmpeg to required executables if user wants media files to be compressed
+        if (self.compress_media): required_executables.append("ffmpeg")
+        ## add "unoconv" (libreoffice package) to required executables of user wants emf files compressed
+        if (self.use_libreoffice): required_executables.append("unoconv")
+
+        for expected_cmd in required_executables:
             if which(expected_cmd) is None:
                 raise CompressPptxError(
                     f"ImageMagick '{expected_cmd}' not found in PATH. Make sure you have installed ImageMagick and that the '{expected_cmd}' command is available."
@@ -105,10 +136,10 @@ class CompressPptx:
             self._unzip()
 
             # Collect compressible files
-            self._find_images()
+            self._find_files()
 
             # Compress
-            self._compress_images()
+            self._compress_files()
 
             # Replace rels
             self._replace_rels()
@@ -126,18 +157,33 @@ class CompressPptx:
             if self.verbose:
                 print(f"Extracted temp files to {self.temp_dir}")
 
-    def _find_images(self) -> None:
+    def _check_endswith(self,filename, extensions):
+        for ext in extensions:
+            if filename.endswith(ext):
+                return True
+        return False
+
+    def _find_files(self) -> None:
         if self.temp_dir is None:
             raise RuntimeError("Temp dir not created!")
 
         for file in glob.iglob(
             os.path.join(self.temp_dir, "ppt", "media", "*"), recursive=True
         ):
+            is_image = True
+            output_extension = self.converted_image_extension
             # skip unaffected extensions
-            if not (
-                file.endswith(".png") or file.endswith(".emf") or file.endswith(".tiff")
-            ):
-                continue
+            if not (self._check_endswith(file, self.image_extensions)): # is not an image
+                if (self.compress_media): # and is also not a media (and compressing media enabled)
+                    is_image = False
+                    if (self._check_endswith(file, self.video_extensions)):
+                        output_extension = self.converted_video_extensions
+                    elif (self._check_endswith(file, self.audio_extensions)):
+                        output_extension = self.converted_audio_extensions
+                    else:
+                        continue ## file is not a media file
+                else:
+                    continue ## file is not an image
 
             # skip files that are too small
             fsize = file_size(file)
@@ -145,21 +191,25 @@ class CompressPptx:
                 # print(f"Skipping {Path(file).name} because it is too small")
                 continue
 
-            # skip files with transparency
-            if self.skip_transparent_images and _has_transparency(file, self.verbose):
-                if self.verbose:
-                    print(f"Skipping {Path(file).name} because it contains transparency")
-                continue
+            if (is_image): # image file
+                # skip files with transparency
+                if self.skip_transparent_images and _has_transparency(file, self.verbose):
+                    if self.verbose:
+                        print(f"Skipping {Path(file).name} because it contains transparency")
+                    continue
 
             if self.verbose:
                 print(
                     f"{Path(file).name} added to conversion queue ({human_readable_size(fsize)})"
                 )
 
-            self.image_list.append(
+            
+
+            self.file_list.append(
                 {
+                    "is_image": is_image,
                     "input": file,
-                    "output": Path(file).parent / (Path(file).stem + "-compressed.jpg"),
+                    "output": Path(file).parent / (Path(file).stem + "-compressed"+output_extension),
                     "input_size": fsize,
                     "output_size": None,
                     "quality": self.quality,
@@ -168,33 +218,58 @@ class CompressPptx:
                 }
             )
 
-    def _compress_images(self) -> None:
-        if len(self.image_list) == 0:
-            print("No images to compress!")
+    def _libreoffice_compress_files(self, files):
+        for file in files:
+            cmd = [
+                "unoconv",
+                "-f",
+                "jpg",
+                "-o",
+                file["output"],
+                file["input"],
+            ]
+            run_command(cmd, verbose=file['verbose'])
+
+    def _compress_files(self) -> None:
+        if len(self.file_list) == 0:
+            print("No Files to compress!")
             return
 
-        print(f"Compressing {len(self.image_list)} file(s) ...")
-
-        for image in self.image_list:
+        for file in self.file_list:
             if self.verbose:
-                print(f"Compressing {image['input']} to {image['output']}")
+                print(f"Compressing {file['input']} to {file['output']}")
 
-        process_map(_compress_image, self.image_list)
+        # compress files with "convert" and "ffmpeg" in parallel
+        non_emf_files = [f for f in self.file_list if not f['input'].endswith(".emf")]
+        print(f"Compressing {len(non_emf_files)} file(s) ...")
+        process_map(_compress_file, non_emf_files)
+
+
+        emf_files = [f for f in self.file_list if f['input'].endswith(".emf")]
+        if (len(emf_files) > 0):
+            print(f"Compressing {len(emf_files)} .EMF file(s) ...")
+            if (self.use_libreoffice):
+                # compress ".emf" (microsoft) files using libreoffice sequentially
+                # (idk why, but it dosent work in parallel)
+                self._libreoffice_compress_files(emf_files)
+            else:
+                # compress ".emf" files using "convert" which works only on windows
+                process_map(_compress_file, emf_files)
 
         # remove borked files
         warnings = []
-        for image in self.image_list:
-            if not Path(image["output"]).exists():
-                print(f"Warning: could not convert {image['input']}")
-                warnings.append(image)
+        for file in self.file_list:
+            if not Path(file["output"]).exists():
+                print(f"Warning: could not convert {file['input']}")
+                warnings.append(file)
+            else:
+                output_size = file_size(file["output"])
+                file["output_size"] = output_size
 
-            output_size = file_size(image["output"])
-            image["output_size"] = output_size
-
-        [self.image_list.remove(w) for w in warnings]
+        [self.file_list.remove(w) for w in warnings]
 
         # delete originals
-        [os.remove(f["input"]) for f in self.image_list]
+        [os.remove(f["input"]) for f in self.file_list]
 
     def _replace_rels(self) -> None:
         if self.temp_dir is None:
@@ -210,9 +285,9 @@ class CompressPptx:
             with open(str(file)) as f:
                 content = f.read()
 
-                for image in self.image_list:
-                    original_file = Path(image["input"]).name
-                    target_file = Path(image["output"]).name
+                for compress_file in self.file_list:
+                    original_file = Path(compress_file["input"]).name
+                    target_file = Path(compress_file["output"]).name
 
                     if original_file not in content:
                         continue
